@@ -181,7 +181,11 @@ class MWCShellConfig(SetupTask):
 
     def run_task(self):
         with self.platform_rc_file().open('a') as fh:
-            fh.write(f"\n# MAKING WITH CODE\nsource {get_mwc_rc_path()}")
+            result = run("which mwc", shell=True, check=True, capture_output=True)
+            mwcpath = Path(result.stdout).parent
+            fh.write(f"\n# MAKING WITH CODE\n")
+            fh.write(f'export PATH="{mwcpath}:$PATH"\n')
+            fh.write(f"source {get_mwc_rc_path()}\n")
         self.mwc_rc_file.write_text("")
         
     def platform_rc_file(self):
@@ -222,6 +226,7 @@ class InstallXCode(SetupTask):
         click.echo(address(msg))
         run("xcode-select --install", shell=True, check=True)
 
+# For Isaak, this installed Poetry but didn't add it to the path. Maybe we should use homebrew instead?
 class InstallPoetry(SetupTask):
     description = "Install poetry"
 
@@ -296,6 +301,9 @@ class InstallPython3(InstallPackage):
 class InstallGit(InstallPackage):
     package_name = brew_name = apt_name = "git"
 
+class InstallTree(InstallPackage):
+    package_name = brew_name = apt_name = "tree"
+
 class InstallAtom(InstallPackage):
     platform = Platform.MAC
     package_name = brew_name = apt_name = "atom"
@@ -315,6 +323,8 @@ class GHAuthentication(SetupTask):
 
     def run_task(self):
         click.echo(address("You will now be prompted to log in to github.com (or to create an account)."))
+        click.echo(address(" - Choose 'GitHub.com' when asked which account you want to log into."))
+        click.echo(address(" - Choose 'HTTPS' when asked which protocol to use"))
         run("gh auth login", shell=True, check=True)
 
     def gh_auth_data(self):
@@ -322,3 +332,6 @@ class GHAuthentication(SetupTask):
             return yaml.safe_load(self.gh_auth_file.read_text())
         else:
             return {}
+
+#class GitConfiguration(SetupTask):
+    #"git config --global init.defaultBranch <name>"
